import { Component, ElementRef, EventEmitter, Input, NgModule, Output } from '@angular/core';
import { CommonModule } from '@angular/common';
import { MatButtonModule, MatIconModule, MatMenuModule, MatToolbarModule } from '@angular/material';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';

var PenSpinnerComponent = (function () {
    /**
     * @param {?} elementRef
     */
    function PenSpinnerComponent(elementRef) {
        var _this = this;
        this.elementRef = elementRef;
        this._defaultSpinnerSrc = './assets/images/ajax-small-loader.gif';
        this._spinnerSrc = '';
        this.isShow = true;
        this.setSpinnerSize = function () {
            if (!_this.elementRef.nativeElement)
                return;
            _this.elementRef.nativeElement.style.width = _this.height || 'auto';
            _this.elementRef.nativeElement.style.width = _this.width || 'auto';
        };
    }
    Object.defineProperty(PenSpinnerComponent.prototype, "spinnerSrc", {
        /**
         * @return {?}
         */
        get: function () {
            return (this._spinnerSrc && this._spinnerSrc.trim() && this._spinnerSrc.length > 0) ? this._spinnerSrc.trim() : this._defaultSpinnerSrc;
        },
        /**
         * @param {?} spinnerUrl
         * @return {?}
         */
        set: function (spinnerUrl) {
            this._spinnerSrc = (spinnerUrl && spinnerUrl.trim() && spinnerUrl.length > 0) ? spinnerUrl.trim() : this._defaultSpinnerSrc;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    PenSpinnerComponent.prototype.ngOnInit = function () {
    };
    /**
     * @return {?}
     */
    PenSpinnerComponent.prototype.ngAfterContentInit = function () {
    };
    return PenSpinnerComponent;
}());
PenSpinnerComponent.decorators = [
    { type: Component, args: [{
                selector: 'pen-spinner',
                template: "<section class=\"penetrace-spinner\" *ngIf=\"(isShow)\" [ngClass]=\"{ backdrop: backdrop}\"> <div class=\"penetrace-spinner__img-group\"> <img class=\"penetrace-spinner__logo\" src=\"{{logoSrc}}\" /> <img class=\"penetrace-spinner__spinner-icon\" src=\"{{spinnerSrc}}\" /> </div> </section>",
                styles: [".penetrace-spinner { position: absolute; top: 0; z-index: 1060; width: 100%; height: 100%; min-height: 50px; text-align: center; } .penetrace-spinner.backdrop { background-color: rgba(0, 0, 0, 0.15); } .penetrace-spinner:before { content: ''; display: inline-block; height: 100%; vertical-align: middle } .penetrace-spinner__img-group { display: inline-block; vertical-align: middle; } .penetrace-spinner__logo { display: block; } .penetrace-spinner__spinner-icon { max-width: 40px; max-height: 40px; } .penetrace-spinner img { /* position: absolute; top: 50%; left: 50%; z-index: 1200; margin-top: -15px; margin-left: -15px; */ } .penetrace-spinner .loader-logo img { width: 140px; margin-left: -67px; margin-top: -110px; height: auto; }"]
            },] },
];
/**
 * @nocollapse
 */
PenSpinnerComponent.ctorParameters = function () { return [
    { type: ElementRef, },
]; };
PenSpinnerComponent.propDecorators = {
    'logoSrc': [{ type: Input },],
    'spinnerSrc': [{ type: Input, args: ['spinnerSrc',] },],
    'backdrop': [{ type: Input },],
    'isShow': [{ type: Input },],
    'width': [{ type: Input },],
    'height': [{ type: Input },],
};

var PenSpinnerModule = (function () {
    function PenSpinnerModule() {
    }
    return PenSpinnerModule;
}());
PenSpinnerModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                exports: [PenSpinnerComponent, CommonModule],
                declarations: [PenSpinnerComponent],
                providers: [],
            },] },
];
/**
 * @nocollapse
 */
PenSpinnerModule.ctorParameters = function () { return []; };

var PenNavbarComponent = (function () {
    function PenNavbarComponent() {
        this.clickHomeIcon = new EventEmitter();
        this.clickToggleIcon = new EventEmitter();
        this.selectLanguage = new EventEmitter();
        this.selectProfileSetting = new EventEmitter();
        this._defaultOptions = {
            showHomeIcon: true,
            showToggleIcon: true,
            showLanguage: true,
            showProfileSettings: true
        };
        this._defaultLanguageList = [
            { title: 'English', id: 'en' },
            { title: 'Norweigian', id: 'no' },
            { title: 'Danish', id: 'da' },
            { title: 'Swedish', id: 'sw' }
        ];
        this._defaultProfileSettingList = [
            { title: 'Edit Profile', id: 'edit' },
            { title: 'My Tasks', id: 'tasks' },
            { title: 'My Reports', id: 'reports' },
            { title: 'Log out', id: 'logout' },
        ];
    }
    /**
     * @return {?}
     */
    PenNavbarComponent.prototype.ngOnInit = function () {
        this._defaultOptions = Object.assign(this._defaultOptions, this.options);
        this._defaultLanguageList = Object.assign(this._defaultLanguageList, this.languageList);
        this._defaultProfileSettingList = Object.assign(this._defaultProfileSettingList, this.profileSettingList);
    };
    /**
     * @return {?}
     */
    PenNavbarComponent.prototype.onHomeIconClicked = function () {
        this.clickHomeIcon.emit();
    };
    /**
     * @return {?}
     */
    PenNavbarComponent.prototype.onToggleIconClicked = function () {
        this.clickToggleIcon.emit();
    };
    /**
     * @param {?} lang
     * @return {?}
     */
    PenNavbarComponent.prototype.onLanguageSelected = function (lang) {
        this.selectLanguage.emit(lang);
    };
    /**
     * @param {?} setting
     * @return {?}
     */
    PenNavbarComponent.prototype.onProfileSettingSelected = function (setting) {
        this.selectProfileSetting.emit(setting);
    };
    return PenNavbarComponent;
}());
PenNavbarComponent.decorators = [
    { type: Component, args: [{
                selector: 'pen-navbar',
                template: "<mat-toolbar color=\"{{color || 'primary'}}\"> <button *ngIf=\"_defaultOptions.showHomeIcon\" mat-icon-button (click)=\"onHomeIconClicked()\"> <mat-icon>home</mat-icon> </button> <button *ngIf=\"_defaultOptions.showToggleIcon\" mat-icon-button (click)=\"onToggleIconClicked()\"> <mat-icon>reorder</mat-icon> </button> <span class=\"fill-remaining-space\"></span> <button *ngIf=\"_defaultOptions.showLanguage\" mat-button [matMenuTriggerFor]=\"language\"> English <mat-icon>keyboard_arrow_down</mat-icon>         </button> <mat-menu #language=\"matMenu\"> <button mat-menu-item *ngFor=\"let lang of _defaultLanguageList\" (click)=\"onLanguageSelected(lang)\">{{lang.title}}</button>         </mat-menu> <button *ngIf=\"_defaultOptions.showProfileSettings\" mat-button [matMenuTriggerFor]=\"profileSettings\"> <mat-icon>account_circle</mat-icon> Name LastName <mat-icon>keyboard_arrow_down</mat-icon> </button> <mat-menu #profileSettings=\"matMenu\"> <button mat-menu-item *ngFor=\"let setting of _defaultProfileSettingList\" (click)=\"onProfileSettingSelected(setting)\">{{setting.title}}</button>        </mat-menu> </mat-toolbar>",
                styles: [".fill-remaining-space { flex: 1 1 auto;     } .mat-menu-panel { width: 150px; }"]
            },] },
];
/**
 * @nocollapse
 */
PenNavbarComponent.ctorParameters = function () { return []; };
PenNavbarComponent.propDecorators = {
    'color': [{ type: Input },],
    'options': [{ type: Input },],
    'languageList': [{ type: Input },],
    'profileSettingList': [{ type: Input },],
    'clickHomeIcon': [{ type: Output },],
    'clickToggleIcon': [{ type: Output },],
    'selectLanguage': [{ type: Output },],
    'selectProfileSetting': [{ type: Output },],
};

var PenNavbarModule = (function () {
    function PenNavbarModule() {
    }
    return PenNavbarModule;
}());
PenNavbarModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, MatToolbarModule, MatIconModule, MatMenuModule, MatButtonModule],
                exports: [PenNavbarComponent, CommonModule, MatToolbarModule, MatIconModule, MatMenuModule, MatButtonModule],
                declarations: [PenNavbarComponent],
                providers: [],
            },] },
];
/**
 * @nocollapse
 */
PenNavbarModule.ctorParameters = function () { return []; };

var PenetraceFrontendFoundationModule = (function () {
    function PenetraceFrontendFoundationModule() {
    }
    /**
     * @return {?}
     */
    PenetraceFrontendFoundationModule.forRoot = function () {
        return {
            ngModule: PenetraceFrontendFoundationModule,
            providers: []
        };
    };
    return PenetraceFrontendFoundationModule;
}());
PenetraceFrontendFoundationModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, BrowserAnimationsModule],
                exports: [PenSpinnerModule, PenNavbarModule],
                declarations: [],
                providers: [],
            },] },
];
/**
 * @nocollapse
 */
PenetraceFrontendFoundationModule.ctorParameters = function () { return []; };

export { PenetraceFrontendFoundationModule, PenSpinnerComponent, PenNavbarComponent };
